<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Projects extends CI_Controller {
	
	public function __construct(){
        parent::__construct();
        if (!$this->ion_auth->logged_in()) redirect('login');  
        $this->load->model("project_model");           
    }
	
	public function index()
	{
		$this->load->library('grocery_CRUD');
		
		$crud = new grocery_CRUD();
		$crud->set_table('projects');
		
		if ($this->ion_auth->in_group("client")){
			$crud->where("projects.client", $this->ion_auth->user()->row()->id);
		}
		
		$crud->columns("name", "client", "description", "created");
		$crud->fields("name", "client", "description", "created");
		$crud->change_field_type('created','invisible');
		$crud->set_relation('client','users','company',array('active' => 1));
		$crud->display_as("name", "Meno");
		$crud->display_as("client", "Klient");
		$crud->display_as("description", "Popis");
		$crud->display_as("created", "Vytvorené");
		
		$crud->add_action('Zobraziť úlohy', '', 'tasks/project', 'ui-icon-tag');
		
		if ($this->ion_auth->in_group("admin")){
		$crud->add_action('Ganttov graf', '', 'projects/gantt', 'ui-icon-note');
		$crud->add_action('PERT Tabuľka', '', 'projects/pert', 'ui-icon-clipboard');
		} else {
			$crud->unset_delete();
			$crud->unset_add();
		}
		
		if ($this->ion_auth->in_group("clients")){
			$crud->unset_edit();
		}
		
		$crud->callback_before_insert(array($this,'_get_time'));
		
		$data = array();
		
		$data["heading"] = "Projekty";
 
		$data["crud"] = $crud->render();
		$this->template->set('js_files', $data["crud"]->js_files);
		$this->template->set('css_files', $data["crud"]->css_files);
		$this->template->load('template', 'pages/crud', $data);

	}
	
	public function gantt($id){
		
		if ($id == "") redirect("projects");
		
		$data = array();
		
		$data["tasks"] = $this->project_model->getProjectTasks($id);
		
		$this->template->load('template', 'pages/gantt', $data);
	}
	
	public function pert($id){
		
		if ($id == "") redirect("projects");
		
		$data = array();
		
		$data["tasks"] = $this->project_model->getProjectTasks($id);
		
		foreach ($data["tasks"] as $id => $task){
			$data["tasks"][$id]["prerequisite"] = $this->project_model->getPrerequisiteName($task["prerequisite"]);
		}
		
		
		$this->template->load('template', 'pages/pert', $data);
	}

	
	function _get_time($post_array) {
		
		$post_array['created'] = date("Y-m-d H:i:s");

		return $post_array;
	} 
	
}
