<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Tasks extends CI_Controller {
	
	public function __construct(){
        parent::__construct();
        if (!$this->ion_auth->logged_in()) redirect('login');     
        $this->load->model("tasks_model");        
    }
	
	public function index()
	{	
		if ($this->ion_auth->in_group("client")) redirect('home'); 

		
		$this->load->library('grocery_CRUD');
		
		$crud = new grocery_CRUD();
		$crud->set_table('tasks');
		
		$crud->where("tasks.created_by", $this->ion_auth->user()->row()->id);
		$crud->or_where("tasks.user", $this->ion_auth->user()->row()->id);
		
		$crud->columns("name", "project", "last_update", "type", "status", "prerequisite");
		$crud->fields("name", "project", "created_by", "created", "last_update", "type", "status", "text", "user", "prerequisite", "time");
		$crud->set_relation('type','task_type','name');
		$crud->set_relation('user','users','username');
		$crud->set_relation('status','task_status','name');
		$crud->set_relation('prerequisite','tasks','name');
		$crud->set_relation('project','projects','name');
		
		
		$crud->callback_before_insert(array($this,'_create_new_task'));
		
		$crud->unset_read();
		
		$crud->add_action('Komentáre úlohy', '', 'tasks/task', 'ui-icon-tag');
		
		
		$crud->change_field_type('created','invisible');
		$crud->change_field_type('created_by','invisible');
		$crud->change_field_type('last_update','invisible');
		
		$crud->display_as("name", "Meno");
		$crud->display_as("created_by", "Vytvoril");
		$crud->display_as("created", "Vytvorené");
		$crud->display_as("last_update", "Posledná zmena");
		$crud->display_as("type", "Typ úlohy");
		$crud->display_as("status", "Stav");
		$crud->display_as("prerequisite", "Prerekvizita");
		$crud->display_as("time", "Predpokladaný čas");
		$crud->display_as("user", "Pracovník");
		$crud->display_as("text", "Popis");
		$crud->display_as("attached", "Spolupracovníci");
		
		
				
		$data = array();
		
		$data["heading"] = "Úlohy" ;
 
		$data["crud"] = $crud->render();
		$this->template->set('js_files', $data["crud"]->js_files);
		$this->template->set('css_files', $data["crud"]->css_files);
		$this->template->load('template', 'pages/crud', $data);

	}
	
	public function project($project_id = null)
	{	
		if ($project_id == null) redirect("tasks");
		
		$this->load->library('grocery_CRUD');
		
		$crud = new grocery_CRUD();
		
		$crud->set_table('tasks');
		$crud->where('tasks.project', $project_id);
		
		if ($this->ion_auth->in_group("workers")) $crud->where(array('tasks.project' => $project_id, "tasks.user" => $this->ion_auth->user()->row()->id));
		
		$crud->columns("name", "last_update", "type", "status", "prerequisite");
		$crud->fields("name", "project", "created_by", "created", "last_update", "type", "status", "text", "user", "prerequisite", "time");
		$crud->set_relation('type','task_type','name');
		$crud->set_relation('user','users','username');
		$crud->set_relation('status','task_status','name');
		$crud->set_relation('prerequisite','tasks','name', array('project' => $project_id));
		
		
		$crud->callback_before_insert(array($this,'_create_new_task'));
		
		$crud->unset_read();
		
		if (!$this->ion_auth->in_group("admin")){
			$crud->unset_delete();
			$crud->unset_add();
			$crud->unset_edit();
		}
		if (!$this->ion_auth->in_group("clients")){
		$crud->add_action('Komentáre úlohy', '', 'tasks/task', 'ui-icon-tag');
		}
		
		$crud->change_field_type('created','invisible');
		$crud->change_field_type('created_by','invisible');
		$crud->change_field_type('last_update','invisible');
		$crud->field_type('project','hidden', $project_id);
		
		$crud->display_as("name", "Meno");
		$crud->display_as("created_by", "Vytvoril");
		$crud->display_as("created", "Vytvorené");
		$crud->display_as("last_update", "Posledná zmena");
		$crud->display_as("type", "Typ úlohy");
		$crud->display_as("status", "Stav");
		$crud->display_as("prerequisite", "Prerekvizita");
		$crud->display_as("time", "Predpokladaný čas");
		$crud->display_as("user", "Pracovník");
		$crud->display_as("text", "Popis");
		$crud->display_as("attached", "Spolupracovníci");
		
		
				
		$data = array();
		
		$data["heading"] = "Úlohy projektu ".$this->tasks_model->getProjectName($project_id);
 
		$data["crud"] = $crud->render();
		$this->template->set('js_files', $data["crud"]->js_files);
		$this->template->set('css_files', $data["crud"]->css_files);
		$this->template->load('template', 'pages/crud', $data);

	}
	
		public function task($task_id = null){
		$this->load->library('grocery_CRUD');
		
		$crud = new grocery_CRUD();
		$crud->set_table('task_message');
		$crud->where('task', $task_id);		
		
		$crud->columns("message", "author", "modified");
		$crud->fields("author", "task", "created", "modified", "message");
		
		$crud->field_type('task','hidden', $task_id);
		$crud->set_relation("author", "users", "username");
		$crud->change_field_type('author','invisible');
		$crud->change_field_type('created','invisible');
		$crud->change_field_type('modified','invisible');
		
		$crud->display_as("author", "Autor");
		$crud->display_as("modified", "Posledná zmena");
		$crud->display_as("message", "Správa");
		
		$crud->callback_before_insert(array($this,'_create_new_comment'));
		
		$crud->callback_before_update(array($this, '_update_comment'));
				
		$data = array();
		
		$data["heading"] = "Priebeh úlohy";
		$data["details"] = $this->tasks_model->getTaskDetails($task_id);
		$data["states"] = $this->tasks_model->getStates();
		
		$data["crud"] = $crud->render();
		$this->template->set('js_files', $data["crud"]->js_files);
		$this->template->set('css_files', $data["crud"]->css_files);
		$this->template->load('template', 'pages/task-detail', $data);

	}
	
	
	function _create_new_comment($post_array) {
		
		$post_array['created'] = date("Y-m-d H:i:s");
		$post_array['author'] = $this->ion_auth->user()->row()->id;
		$post_array['modified'] = date("Y-m-d H:i:s");
		
		return $post_array;
	} 
	
	function _update_comment($post_array) {
		
		$post_array['modified'] = date("Y-m-d H:i:s");
		
		return $post_array;
	} 

		
	function _create_new_task($post_array) {
		
		$post_array['created'] = date("Y-m-d H:i:s");
		$post_array['created_by'] = $this->ion_auth->user()->row()->id;
		$post_array['last_update'] = date("Y-m-d H:i:s");
		$post_array['status'] = 1;
		
		return $post_array;
	} 
	
}
